import React, { Component } from "react";
import "./App.css";

type Props = {};

type State = {
  isLoading: boolean;
  passed?: boolean;
  failMessage?: string;
};

export default class App extends Component<Props, State> {
  constructor(props: Props) {
    super(props);

    this.state = {
      isLoading: true,
    };
  }

  componentDidMount() {
    this.runTest();
  }

  getChromeVersion() {
    // From: https://stackoverflow.com/a/4900484
    var raw = navigator.userAgent.match(/Chrom(e|ium)\/([0-9]+)\./);
    return raw ? parseInt(raw[2], 10) : false;
  }

  pass() {
    this.setState({
      passed: true,
      isLoading: false,
    });
  }

  fail(msg: string) {
    this.setState({
      passed: false,
      isLoading: false,
      failMessage: msg,
    });
  }

  runTest() {
    var version = this.getChromeVersion();
    if (!version) {
      this.fail("You must use Google Chrome, version 60 or above");
      return;
    }
    if (version < 60) {
      this.fail("You must use version 60 or above of Google Chrome");
      return;
    }

    fetch("http://localhost:3265/test")
      .then((response) => response.json())
      .then((json) => {
        if (json.ok) {
          this.pass();
        } else {
          this.fail("received invalid response from server");
        }
      })
      .catch((error) => {
        this.fail(
          "Fetching test data failed. Did you run one of the servers before opening this file?"
        );
      });
  }

  render() {
    if (this.state.isLoading) {
      return <span>Loading...</span>;
    }

    if (this.state.passed) {
      return (
        <div id="success">
          <div className="content">
            <div className="icon">
              <span
                className="glyphicon glyphicon-ok"
                aria-hidden="true"
              ></span>
            </div>
            Success! You're all set for the interview.
          </div>
        </div>
      );
    }

    return (
      <div id="failure">
        <div className="content">
          <div className="icon">
            <span
              className="glyphicon glyphicon-remove-circle"
              aria-hidden="true"
            ></span>
          </div>
          Uh oh! There was an issue:{" "}
          <span id="failure-message">{this.state.failMessage}</span>
          <br />
          <br />
          Please contact us for help debugging.
        </div>
      </div>
    );
  }
}
